# OpenQuake Hazardlib

![OpenQuake Logo](https://www.globalquakemodel.org/media/storage/oq-logo.png)

The OpenQuake Hazard Library is open-source software for performing seismic hazard analysis.

## About

hazardlib includes modules for modeling seismic sources (point, area and fault), earthquake ruptures, temporal (e.g. Poissonian) and magnitude occurrence models (e.g. Gutenberg-Richter), magnitude/area scaling relationships, ground motion and intensity prediction equations (i.e. GMPEs and IPEs).
Eventually it will offer a number of calculators for hazard curves, stochastic event sets, ground motion fields and disaggregation histograms.

hazardlib aims at becoming an open and comprehensive tool for seismic hazard analysis. The [GEM Foundation](http://www.globalquakemodel.org/) supports
the development of the  library by adding the most recent methodologies
adopted by the seismological/seismic hazard communities. Comments,
suggestions and criticisms from the community are always very welcome.

## Documentation

* [Source Code/API Documentation](http://docs.openquake.org/oq-hazardlib/)
* [Continuous integration and testing](https://github.com/gem/oq-hazardlib/blob/engine-2.4/doc/testing.md)

### Installation

* [Technology stack and requirements](https://github.com/gem/oq-hazardlib/blob/engine-2.4/doc/requirements.md)
* [Installing from sources](https://github.com/gem/oq-hazardlib/blob/engine-2.4/doc/development.md)

The OpenQuake Hazardlib is also distributed in the form of **binary package** for Linux, macOS and Windows as part of the [OpenQuake Engine](https://github.com/gem/oq-engine/) suite. See the [OpenQuake Engine README](https://github.com/gem/oq-engine/blob/engine-2.4/README.md#installation) for more information.

### Development

* [Implementing a new GSIM](https://github.com/gem/oq-hazardlib/blob/engine-2.4/doc/implementing-new-gsim.md)

## License

The OpenQuake Hazardlib is released under the **[GNU Affero Public License 3](https://github.com/gem/oq-hazardlib/blob/engine-2.4/LICENSE)**.

## Contacts

* Support forum: https://groups.google.com/forum/#!forum/openquake-users
* Twitter: [@gem_hazard](https://twitter.com/gem_hazard) | [@gem_devs](https://twitter.com/gem_devs)
* Email: info@openquake.org
* IRC: [irc.freenode.net](https://webchat.freenode.net/), channel #openquake

## Thanks

The OpenQuake Hazardlib is developed by the **[Global Earthquake Model Foundation (GEM)](http://gem.foundation)** with the support of
![](https://www.globalquakemodel.org/media/sponsor/aus.png)
![](https://www.globalquakemodel.org/media/sponsor/cidigen.png)
![](https://www.globalquakemodel.org/media/sponsor/sg_170x104.jpg)
![](https://www.globalquakemodel.org/media/sponsor/gfz.png)
![](https://www.globalquakemodel.org/media/sponsor/pcn.jpg)
![](https://www.globalquakemodel.org/media/sponsor/nied.png)
![](https://www.globalquakemodel.org/media/sponsor/nset.png)
![](https://www.globalquakemodel.org/media/sponsor/morst.jpg)
![](https://www.globalquakemodel.org/media/sponsor/RCN.jpg)
![](https://www.globalquakemodel.org/media/sponsor/swiss_1.jpg)
![](https://www.globalquakemodel.org/media/sponsor/tem.jpg)
![](https://www.globalquakemodel.org/media/sponsor/TCIP-01.png)
![](https://www.globalquakemodel.org/media/sponsor/nerc.png)
![](https://www.globalquakemodel.org/media/sponsor/usaid_BsOsE8Z_QZnaG6c.jpg)
![](https://www.globalquakemodel.org/media/sponsor/FUNVISIS_GEM_logo.png)

***

![](https://www.globalquakemodel.org/media/sponsor/FMGlobal.jpg)
![](https://www.globalquakemodel.org/media/sponsor/hannoverRe.jpg)
![](https://www.globalquakemodel.org/media/sponsor/Nephila.jpg)
![](https://www.globalquakemodel.org/media/sponsor/munichre_HwOCwR4.jpg)
![](https://www.globalquakemodel.org/media/sponsor/zurich_3eh504q.jpg)
![](https://www.globalquakemodel.org/media/sponsor/Air_JlQh6Ke.jpg)
![](https://www.globalquakemodel.org/media/sponsor/sur_170x104.jpg)
![](https://www.globalquakemodel.org/media/sponsor/EUCENTRE_BRAw8x4.jpg)
![](https://www.globalquakemodel.org/media/sponsor/GiroJ.jpg)
![](https://www.globalquakemodel.org/media/sponsor/arup.jpg)
![](https://www.globalquakemodel.org/media/sponsor/OYO_1.jpg)

***

![](https://www.globalquakemodel.org/media/sponsor/OECD.jpg)
![](https://www.globalquakemodel.org/media/sponsor/worldbank_2.jpg)
![](https://www.globalquakemodel.org/media/sponsor/ISDR.jpg)
![](https://www.globalquakemodel.org/media/sponsor/Unesco.jpg)
![](https://www.globalquakemodel.org/media/sponsor/iaspei.jpg)
![](https://www.globalquakemodel.org/media/sponsor/iaee.jpg)
![](https://www.globalquakemodel.org/media/sponsor/istructe.jpg)
![](https://www.globalquakemodel.org/media/sponsor/cssc.jpg)
![](https://www.globalquakemodel.org/media/sponsor/IRDRICSU.png)
![](https://www.globalquakemodel.org/media/sponsor/EERI_GEM.png)

For more info visit the GEM website at https://www.globalquakemodel.org/gem/organisation/partners/
